from fastapi import APIRouter, Query, Form

from app.common import util
from app.common.schema import ApiResultSchema
from app.common.response import ApiResult

router = APIRouter()


@router.post("/login", name="用户登录", description="""
#### 测试数据
- username: `zhangsan`
- pwssword: `e10adc3949ba59abbe56e057f20f883e`
- sign: `h9Ki9eMChBhjWU/aCeqlkLcCNBchnfIt3U2V6MSIF/Rl0WoD1iqM8TKH3U8ZmFoq`
""", response_model=ApiResultSchema)
async def login(
        username: str = Form(..., title="用户名", description="用户名"),
        password: str = Form(..., title="密码", description="密码，算法：`md5(password)`"),
        sign: str = Form(..., title="签名", description="签名，算法：`aes(username+password)`"),
):
    if sign is None or util.aes_decrypt(_key, sign) != username + password:
        return ApiResult.error_msg("签名不正确")
    if username != _username:
        return ApiResult.error_msg("用户名不存在")
    if password != util.md5(_password):
        return ApiResult.error_msg("密码不正确")
    return ApiResult.success_data({"token": _token})


@router.get("/list", name="小说列表", description="""
## 测试数据
- token: `e9d8edc1-400c-436f-880c-9cd8392745ca`
""", response_model=ApiResultSchema)
async def list(
        token: str = Query(..., title="令牌", description="令牌"),
):
    if token.encode("utf-8") != _token:
        return ApiResult.error_msg("无权限访问")
    return ApiResult.success_data({"list": _list_data})


# DATA
_key = "4EFA6860A3539903".encode("utf-8")
_username = "zhangsan"
_password = "123456"
_token = "e9d8edc1-400c-436f-880c-9cd8392745ca".encode("utf-8")
_list_data = [
    {
        "image": "http://static.zongheng.com/upload/cover/d0/27/d027db9b2ee2695e8a3d4804dc20da39.jpeg",
        "name": "死囚生存游戏",
        "desc": "2050年，世界各国联合研发出一款用于惩戒重犯的虚拟现实系统：【溟河系统】，该系统可剥夺犯人意识并永久禁锢在虚拟世界中，以达到人性化惩戒重犯的目的。充斥杀机的战场，蛰伏的攻击型生物，13场搏杀游戏，12个死刑犯，3条溟河法则，1个幸存者名额，淘汰者将永远留在系统，成为行尸走肉，为自己【赎罪】；获胜者将重获自由，前罪全免，获得【救赎】……一念天堂，一念地狱，杀与被杀，屠夫与羔羊，你选择哪个？ 【注：溟河三法则：当第一声警报响起时，城市的消防、警卫、医疗、安保等系统会彻底瘫痪，监狱系统将对外开放，游戏进入犯罪无罪的状态。当第二声警报响起时，玩家可以开始屠杀其他玩家，12个玩家的游戏正式开始。当第三声警报响起时，游戏中将会有攻击型生物、猎人出没，追杀游戏玩家】 【注：多主角，剧情向，游戏线与现实线交叉。】"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/54/be/54be6939cd7eeb3d173c09555149a3c5.jpeg",
        "name": "阴阳灵探",
        "desc": "鬼朔和王大灵是被警校开除的学生，二人合开了见鬼灵侦探社，谁知竟接到了一桩桩奇异的案件。。。原来这世间除了有人行凶外，还有其它。。。"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/4c/c5/4cc5125da0ae3f9f17a35ad375cd1c56.jpeg",
        "name": "乱古剑帝",
        "desc": "人间的九月，下起了一场剑雨。我会循着远古战歌的召唤，亦是在无尽的杀伐中，轻声吟唱。"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/bd/ef/bdef0b3920193e62fcf217d2d63713c2.jpeg",
        "name": "狂枭",
        "desc": "生当作人杰，死亦为鬼雄。 这是老子的人生，全部所有内容。"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/f1/5a/f15ae195aba87bfb6eb0ecce403258e5.jpeg",
        "name": "道断修罗",
        "desc": "少年李夜，生下即渡劫，誓要走一条与众不同的修行之路。随先生上天山修行，披一肩风雨，斩一山飞雪......下山回城遇退婚风波，狠心女人欲要斩草除根......行一路烟雨，踏一江春水......少年国师笑傲南疆，灭敌于南云城前......遇外敌内匪，踏修罗刀山......身陷黑洞，降临修罗域，天途道断，且看我如何踏天而行，搅动两界风云。"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/f4/1f/f41f7836f0d7a1b9d81d4c5fa9e230aa.jpeg",
        "name": "血色圣歌",
        "desc": "开场满级主动带飞零级菜鸡：信仰我，带你傲立九界之巅！作为传说中的至尊纯血再世，这口气，墨岚能忍？？ 他能！师父，爸爸，带我飞吧，我不想努力啦！"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/c5/27/c527797d2e392d00831add17d759101f.jpeg",
        "name": "我怎么就不能飞升",
        "desc": "泰山之巅，赵东来双手枕着脑袋，仰躺在一块大石头上，嘴里叼着一根不知道从哪拔来的野草。“贼老天……”赵东来望着天幕，轻声呢喃着：“我做了五十年的好事，救治了无数病人，连碰瓷的我都好心给他们治一治” “我就想问问，为什么我如今修为都快撑破这片天地了，怎么就还没到飞升境？” “我……怎么就不能飞升！”"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/c1/d1/c1d151d7630e03942ad3cb46be0be562.jpeg",
        "name": "神诵九歌",
        "desc": "大夏北境上，几个士兵发现亡灵来袭！ 有易部落内，首领之子即将迎来冒险！ 究竟是怎样的大手，才能弹奏出这壮丽的九歌？ 长夜将至，神、人、亡者的命运又当何去何从？"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/3b/18/3b182c63025a5b518a6a781943d22d7f.jpeg",
        "name": "风云龙婿",
        "desc": "三年潜伏，一朝归来，他依然是王者，曾经失去的，统统都要拿回来，在世人眼中，他是战神，但在心爱的人眼里，他只是个普通的男人。"
    },
    {
        "image": "http://static.zongheng.com/upload/cover/ad/51/ad5199ae6850e50ab8e8d220ec8e2988.jpeg",
        "name": "妖孽哪里走",
        "desc": "“建国以后不许成精！”苏铭霸气的说道。某妖弱弱的问道：“那建国前成精的怎么处理？”"
    }
]
